@@ -199,6 +199,11 @@ bool QDeepinFileDialogHelper::show(Qt::WindowFlags flags, Qt::WindowModality mod
     DIALOG_CALL(show());
 
     if (nativeDialog && parent) {
+        // 如果能获取到wayland下的display 应该 XSetTransientForHint(wayland_dispaly
+        // 此处暂时返回，至少不会导致崩溃。。。task-view-31919.
+        if (qApp->platformName() != "dxcb" && !qApp->property("_d_isDxcb").toBool())
+            return true;
+
         XSetTransientForHint(QX11Info::display(), nativeDialog->winId(), parent->winId());
     }
 
@@ -421,13 +426,13 @@ void QDeepinFileDialogHelper::applyOptions()
         }
     }
 
+    DIALOG_CALL(setOptions((QFileDialog::Options)(int)options->options()));
     DIALOG_CALL(setFilter(options->filter()));
     DIALOG_CALL(setWindowTitle(options->windowTitle()));
     DIALOG_CALL(setViewMode((QFileDialog::ViewMode)options->viewMode()));
     DIALOG_CALL(setFileMode((QFileDialog::FileMode)options->fileMode()));
     DIALOG_CALL(setAcceptMode((QFileDialog::AcceptMode)options->acceptMode()));
     DIALOG_CALL(setNameFilters(options->nameFilters()));
-    DIALOG_CALL(setOptions((QFileDialog::Options)(int)options->options()));
 
     setDirectory(options->initialDirectory());
 
@@ -452,6 +457,11 @@ void QDeepinFileDialogHelper::applyOptions()
                 nativeDialog->addCustomWidget(ComboBoxType, i);
 
             nativeDialog->endAddCustomWidget();
+
+            const QVariant & mixedSelection = sourceDialog->property("_dtk_widget_filedialog_mixed_selection");
+            if (mixedSelection.isValid()) {
+                nativeDialog->setAllowMixedSelection(mixedSelection.toBool());
+            }
         }
     }
 }
