@@ -22,11 +22,15 @@
 #include "dthemesettings.h"
 #include "diconengine.h"
 
+#include <DGuiApplicationHelper>
+#include <DPlatformTheme>
+
 #include <QVariant>
 #include <QDebug>
 #include <QGuiApplication>
 #include <QPainter>
 #include <QPalette>
+#include <QIconEnginePlugin>
 
 #include <XdgIcon>
 #if XDG_ICON_VERSION_MAR >= 3
@@ -55,6 +59,8 @@
 
 #include <cxxabi.h>
 
+DGUI_USE_NAMESPACE
+
 #if XDG_ICON_VERSION_MAR >= 3
 namespace DEEPIN_QT_THEME {
 QThreadStorage<QString> colorScheme;
@@ -138,7 +144,7 @@ public:
                         }
                     }
                 }
-                // duplicate the contets also for opposite state
+                // duplicate the contents also for opposite state
 //                svg_buffers[(QIcon::Normal<<4)|QIcon::On] = svg_buffers[(QIcon::Normal<<4)|QIcon::Off];
 //                svg_buffers[(QIcon::Selected<<4)|QIcon::On] = svg_buffers[(QIcon::Selected<<4)|QIcon::Off];
             }
@@ -259,7 +265,11 @@ public:
             // QIcon::pixmap() multiplies size by the device pixel ratio.
             const int integerScale = qCeil(arg.scale);
             QIconLoaderEngineEntry *entry = engine->entryForSize(arg.size / integerScale, integerScale);
+            // 先禁用缩放，因为此size是已经缩放过的
+            bool useHighDpiPixmap = qGuiApp->testAttribute(Qt::AA_UseHighDpiPixmaps);
+            qGuiApp->setAttribute(Qt::AA_UseHighDpiPixmaps, false);
             arg.pixmap = entry ? pixmapByEntry(entry, arg.size, arg.mode, arg.state) : QPixmap();
+            qGuiApp->setAttribute(Qt::AA_UseHighDpiPixmaps, useHighDpiPixmap);
             DEEPIN_QT_THEME::colorScheme.setLocalData(QString());
 
             return;
@@ -290,6 +300,37 @@ static void onIconThemeSetCallback()
         // emit the signal: DApplication::iconThemeChanged
         qApp->metaObject()->invokeMethod(qApp, QT_STRINGIFY(iconThemeChanged));
     }
+
+    // 通知所有窗口重绘制
+    QEvent update(QEvent::UpdateRequest);
+    for (QWindow *window : qGuiApp->allWindows()) {
+        if (window->type() == Qt::Desktop)
+            continue;
+
+        qApp->sendEvent(window, &update);
+    }
+}
+
+static void onFontChanged()
+{
+    // 先清理旧的font对象
+    if (QGuiApplicationPrivate::app_font)
+        delete QGuiApplicationPrivate::app_font;
+    QGuiApplicationPrivate::app_font = nullptr;
+
+    QEvent event(QEvent::ApplicationFontChange);
+    qApp->sendEvent(qApp, &event);
+
+    // 通知所有窗口字体改变了
+    for (QWindow *window : qGuiApp->allWindows()) {
+        if (window->type() == Qt::Desktop)
+            continue;
+
+        qApp->sendEvent(window, &event);
+    }
+
+    qApp->sendEvent(DGuiApplicationHelper::instance(), &event);
+    Q_EMIT qGuiApp->fontChanged(qGuiApp->font());
 }
 
 static void updateWindowGeometry(QWindow *w)
@@ -516,7 +557,7 @@ static void onAutoScaleWindowChanged()
 static bool updateScaleLogcailDpi(const QPair<qreal, qreal> &dpi)
 {
     bool ok = dpi.first >= 0 && dpi.second >= 0;
-
+#if QT_VERSION < QT_VERSION_CHECK(5,14,0)
     if (dpi.first > 0) {
         QHighDpiScaling::m_logicalDpi.first = dpi.first;
     } else if (qIsNull(dpi.first)) {
@@ -528,7 +569,9 @@ static bool updateScaleLogcailDpi(const QPair<qreal, qreal> &dpi)
     } else if (qIsNull(dpi.second)) {
         QHighDpiScaling::m_logicalDpi.second = qGuiApp->primaryScreen()->handle()->logicalDpi().second;
     }
-
+#else
+    QHighDpiScaling::m_usePixelDensity = false;
+#endif
     return ok;
 }
 
@@ -571,10 +614,18 @@ static bool updateScreenScaleFactors(DThemeSettings *s, const QByteArray &value,
     }
 
     QHighDpiScaling::updateHighDpiScaling();
+#if QT_VERSION < QT_VERSION_CHECK(5,14,0)
     qDebug() << QHighDpiScaling::logicalDpi();
+#else
+    qDebug() << QHighDpiScaling::logicalDpi(QGuiApplication::primaryScreen());
+#endif
     updateScaleLogcailDpi(s->scaleLogicalDpi());
 
+#if QT_VERSION < QT_VERSION_CHECK(5,14,0)
     qDebug() << QHighDpiScaling::logicalDpi();
+#else
+    qDebug() << QHighDpiScaling::logicalDpi(QGuiApplication::primaryScreen());
+#endif
 
     return true;
 }
@@ -595,7 +646,8 @@ static bool enabledRTScreenScale()
                             !qEnvironmentVariableIsSet("QT_AUTO_SCREEN_SCALE_FACTOR") &&
                             !qEnvironmentVariableIsSet("QT_SCREEN_SCALE_FACTORS") &&
                             !QCoreApplication::testAttribute(Qt::AA_DisableHighDpiScaling) &&
-                            !QCoreApplication::testAttribute(Qt::AA_EnableHighDpiScaling);
+                            !QCoreApplication::testAttribute(Qt::AA_EnableHighDpiScaling) &&
+                            qGuiApp->platformName().endsWith("xcb");
 
     return enable;
 }
@@ -656,6 +708,25 @@ QPlatformDialogHelper *QDeepinTheme::createPlatformDialogHelper(DialogType type)
     return QGenericUnixTheme::createPlatformDialogHelper(type);
 }
 
+static QIconEnginePlugin *getBuiltinIconEngineFactory()
+{
+    static QFactoryLoader loader(QIconEngineFactoryInterface_iid, QLatin1String("/iconengines"), Qt::CaseSensitive);
+    int index = loader.indexOf("DBuiltinIconEngine");
+
+    if (index != -1) {
+        return qobject_cast<QIconEnginePlugin *>(loader.instance(index));
+    }
+
+    return nullptr;
+}
+
+static QIconEngine *createBuiltinIconEngine(const QString &iconName)
+{
+    static QIconEnginePlugin *plugin = getBuiltinIconEngineFactory();
+
+    return plugin ? plugin->create(iconName) : nullptr;
+}
+
 QIconEngine *QDeepinTheme::createIconEngine(const QString &iconName) const
 {
 #ifdef DTHEMED_ICON_LOOKUP
@@ -667,18 +738,30 @@ QIconEngine *QDeepinTheme::createIconEngine(const QString &iconName) const
 #elif XDG_ICON_VERSION_MAR < 3
     return XdgIconEngineCreator::create(iconName);
 #else
+    static QSet<QString> non_builtin_icon_cache;
+
+    if (!non_builtin_icon_cache.contains(iconName)) {
+        // 记录下来此种类型的icon为内置图标
+        // 因此，此处添加的缓存不考虑更新
+        // 优先使用内置图标
+        if (QIconEngine *engine = createBuiltinIconEngine(iconName)) {
+            if (engine->isNull()) {
+                non_builtin_icon_cache.insert(iconName);
+                delete engine;
+            } else {
+                return engine;
+            }
+        } else {
+            non_builtin_icon_cache.insert(iconName);
+        }
+    }
+
     return new XdgIconProxyEngine(new XdgIconLoaderEngine(iconName));
 #endif
 }
 
 QPixmap QDeepinTheme::standardPixmap(QPlatformTheme::StandardPixmap sp, const QSizeF &size) const
 {
-    switch (sp) {
-    case ArrowRight:
-        return QPixmap(":/images/arrow-light.png");
-    default: break;
-    }
-
     return QGenericUnixTheme::standardPixmap(sp, size);
 }
 
@@ -698,25 +781,40 @@ QPixmap QDeepinTheme::fileIconPixmap(const QFileInfo &fileInfo, const QSizeF &si
 }
 #endif
 
+static DPlatformTheme *appTheme()
+{
+    static QPointer<DPlatformTheme> theme;
+
+    if (!theme) {
+        theme = DGuiApplicationHelper::instance()->applicationTheme();
+        QObject::connect(theme, &DPlatformTheme::iconThemeNameChanged, &onIconThemeSetCallback);
+        QObject::connect(theme, &DPlatformTheme::fontNameChanged, &onFontChanged);
+        QObject::connect(theme, &DPlatformTheme::fontPointSizeChanged, [] {
+            if (theme->fontName().isEmpty())
+                return;
+
+            onFontChanged();
+        });
+        QObject::connect(theme, &DPlatformTheme::gtkFontNameChanged, [] {
+            if (theme->fontName().isEmpty()) {
+                onFontChanged();
+            }
+        });
+    }
+
+    return theme;
+}
+
 QVariant QDeepinTheme::themeHint(QPlatformTheme::ThemeHint hint) const
 {
     switch (hint) {
     case QPlatformTheme::StyleNames: {
-        if (settings()->isSetStyleNames() && !settings()->styleNames().isEmpty())
-            return settings()->styleNames();
-
-        break;
+        return QStringList({"chameleon", "fusion"});
     }
     case QPlatformTheme::SystemIconThemeName:
-        if (settings()->isSetIconThemeName())
-            return settings()->iconThemeName();
-
-        return QVariant();
+        return appTheme()->iconThemeName();
     case QPlatformTheme::SystemIconFallbackThemeName:
-        if (settings()->isSetFallbackIconThemeName())
-            return settings()->fallbackIconThemeName();
-
-        return QVariant("deepin");
+        return "bloom";
     case QPlatformTheme::IconThemeSearchPaths:
         return QVariant(QGenericUnixTheme::xdgIconThemePaths() << QDir::homePath() + "/.local/share/icons");
     case UseFullScreenForPopupMenu:
@@ -728,6 +826,18 @@ QVariant QDeepinTheme::themeHint(QPlatformTheme::ThemeHint hint) const
     return QGenericUnixTheme::themeHint(hint);
 }
 
+const QPalette *QDeepinTheme::palette(QPlatformTheme::Palette type) const
+{
+    if (type != SystemPalette) {
+        return QGenericUnixTheme::palette(type);
+    }
+
+    static QPalette palette;
+    palette = DGuiApplicationHelper::instance()->applicationPalette();
+
+    return &palette;
+}
+
 const QFont *QDeepinTheme::font(QPlatformTheme::Font type) const
 {
     if (!qApp->desktopSettingsAware())
@@ -735,29 +845,60 @@ const QFont *QDeepinTheme::font(QPlatformTheme::Font type) const
 
     switch (type) {
     case SystemFont:
-        if (settings()->isSetSystemFont()) {
-            static QFont *system_font = new QFont("");
+        if (DPlatformTheme *theme = appTheme()) {
+            QByteArray font_name = theme->fontName();
+            qreal font_size = 0;
 
-            if (!settings()->systemFont().isEmpty()) {
-                system_font->setFamily(settings()->systemFont());
-                system_font->setPointSizeF(settings()->systemFontPointSize());
+            if (font_name.isEmpty()) {
+                font_name = theme->gtkFontName();
+                int font_size_index = font_name.lastIndexOf(' ');
+
+                if (font_size_index <= 0)
+                    break;
+
+                font_size = font_name.mid(font_size_index + 1).toDouble();
+                font_name = font_name.left(font_size_index);
+            } else {
+                font_size = theme->fontPointSize();
             }
 
-            return system_font;
-        }
-        break;
-    case FixedFont:
-        if (settings()->isSetSystemFixedFont()) {
-            static QFont *fixed_font = new QFont("");
-
-            if (!settings()->systemFixedFont().isEmpty()) {
-                fixed_font->setFamily(settings()->systemFixedFont());
-                fixed_font->setPointSizeF(settings()->systemFontPointSize());
+            if (font_size <= 0) {
+                font_size = 10.5;
             }
 
-            return fixed_font;
+            static QFont font = QFont(QString());
+
+            font.setFamily(font_name);
+            font.setPointSizeF(font_size);
+
+            return &font;
         }
+
         break;
+    case FixedFont: {
+        if (DPlatformTheme *theme = appTheme()) {
+            QByteArray font_name = theme->monoFontName();
+
+            if (font_name.isEmpty()) {
+                break;
+            }
+
+            qreal font_size = theme->fontPointSize();
+
+            if (font_size <= 0) {
+                font_size = 10.5;
+            }
+
+            static QFont font = QFont(QString());
+
+            font.setFamily(font_name);
+            font.setPointSizeF(font_size);
+
+            return &font;
+        }
+
+        break;
+    }
     default:
         break;
     }
@@ -797,19 +938,6 @@ DThemeSettings *QDeepinTheme::settings() const
 
         qApp->setProperty("_d_theme_settings_object", (quintptr)m_settings);
 
-        if (qApp->inherits("Dtk::Widget::DApplication")) {
-            QObject::connect(m_settings, SIGNAL(iconThemeNameChanged(QString)),
-                             qApp, SLOT(iconThemeChanged()), Qt::UniqueConnection);
-        }
-
-        auto updateSystemFont = [this] {
-            qApp->setFont(*font(QPlatformTheme::SystemFont));
-        };
-
-        QObject::connect(m_settings, &DThemeSettings::systemFontChanged, m_settings, updateSystemFont, Qt::UniqueConnection);
-        QObject::connect(m_settings, &DThemeSettings::systemFontPointSizeChanged, m_settings, updateSystemFont, Qt::UniqueConnection);
-        QObject::connect(m_settings, &DThemeSettings::iconThemeNameChanged, m_settings, &onIconThemeSetCallback, Qt::UniqueConnection);
-
         if (enabledRTScreenScale()) {
 #ifdef QT_NO_DEBUG
             if (!qEnvironmentVariableIsSet("D_ENABLE_RT_SCALE"))
