@@ -39,6 +39,8 @@
 ****************************************************************************/
 
 #include <QtWidgets>
+#include <QTreeView>
+#include <QFileSystemModel>
 
 #include "norwegianwoodstyle.h"
 #include "widgetgallery.h"
@@ -58,10 +60,12 @@ WidgetGallery::WidgetGallery(QWidget *parent)
     styleLabel->setBuddy(styleComboBox);
 
     useStylePaletteCheckBox = new QCheckBox(tr("&Use style's standard palette"));
-    useStylePaletteCheckBox->setChecked(true);
+    useStylePaletteCheckBox->setChecked(false);
 
     disableWidgetsCheckBox = new QCheckBox(tr("&Disable widgets"));
 
+    changeStyle("chameleon");
+
     createTopLeftGroupBox();
     createTopRightGroupBox();
     createBottomLeftTabWidget();
@@ -108,17 +112,41 @@ WidgetGallery::WidgetGallery(QWidget *parent)
     mainLayout->setColumnStretch(1, 1);
 
     setWindowTitle(tr("Styles"));
-    changeStyle("NorwegianWood");
 
     setCentralWidget(mainWidget);
 
-    menuBar()->addAction("breeze");
+    QMenu *firstLayer = new QMenu("first");
+    menuBar()->addAction("chameleon")->setMenu(firstLayer);
+    firstLayer->addAction("menu 1")->setIcon(QIcon::fromTheme("document-open"));
+    firstLayer->addAction("menu 2")->setEnabled(false);
+    firstLayer->addSection("Section");
+    firstLayer->addAction("menu 3")->setCheckable(true);
+    firstLayer->addSeparator();
+
+    QMenu *secondLayer = new QMenu("second");
+    firstLayer->addMenu(secondLayer);
+    QActionGroup *group = new QActionGroup(this);
+    group->setExclusive(true);
+    QAction *sa1 = new QAction("submenu 1");
+    sa1->setCheckable(true);
+    group->addAction(sa1);
+    QAction *sa2 = new QAction("submenu 2");
+    sa2->setCheckable(true);
+    sa2->setIcon(QIcon::fromTheme("application-exit"));
+    group->addAction(sa2);
+    QAction *sa3 = new QAction("submenu 3");
+    sa3->setCheckable(true);
+    sa3->setShortcut(QKeySequence::New);
+    group->addAction(sa3);
+    secondLayer->addActions(group->actions());
+    secondLayer->setLayoutDirection(Qt::RightToLeft);
+
     menuBar()->addAction("dlight");
     menuBar()->addAction("ddark");
     menuBar()->addAction("dsemidark");
     menuBar()->addAction("dsemilight");
 
-    connect(menuBar(), &QMenuBar::triggered, this, [this](const QAction *action) {
+    connect(menuBar(), &QMenuBar::triggered, this, [this](const QAction * action) {
         changeStyle(action->text());
     });
 }
@@ -141,10 +169,12 @@ void WidgetGallery::changeStyle(const QString &styleName)
 void WidgetGallery::changePalette()
 //! [7] //! [8]
 {
-    if (useStylePaletteCheckBox->isChecked())
+    if (useStylePaletteCheckBox->isChecked()) {
         QApplication::setPalette(QApplication::style()->standardPalette());
-    else
-        QApplication::setPalette(originalPalette);
+     } else {
+//        QApplication::setPalette(originalPalette);
+        QApplication::setAttribute(Qt::AA_SetPalette, false);
+    }
 }
 //! [8]
 
@@ -173,6 +203,18 @@ void WidgetGallery::createTopLeftGroupBox()
     checkBox->setTristate(true);
     checkBox->setCheckState(Qt::PartiallyChecked);
 
+    connect(radioButton1, &QRadioButton::clicked, this, [&] {
+        bottomLeftTabWidget->setDocumentMode(!bottomLeftTabWidget->documentMode());
+    });
+    connect(radioButton2, &QRadioButton::clicked, this, [&] {
+        bottomLeftTabWidget->setTabShape(QTabWidget::Rounded);
+        bottomLeftTabWidget->update();
+    });
+    connect(radioButton3, &QRadioButton::clicked, this, [&] {
+        bottomLeftTabWidget->setTabShape(QTabWidget::Triangular);
+        bottomLeftTabWidget->update();
+    });
+
     QVBoxLayout *layout = new QVBoxLayout;
     layout->addWidget(radioButton1);
     layout->addWidget(radioButton2);
@@ -211,6 +253,9 @@ void WidgetGallery::createBottomLeftTabWidget()
     bottomLeftTabWidget->setSizePolicy(QSizePolicy::Preferred,
                                        QSizePolicy::Ignored);
 
+    bottomLeftTabWidget->setTabsClosable(true);
+    bottomLeftTabWidget->setTabShape(QTabWidget::Triangular);
+
     QWidget *tab1 = new QWidget;
     tableWidget = new QTableWidget(10, 10);
 
@@ -236,6 +281,23 @@ void WidgetGallery::createBottomLeftTabWidget()
 
     bottomLeftTabWidget->addTab(tab1, tr("&Table"));
     bottomLeftTabWidget->addTab(tab2, tr("Text &Edit"));
+
+    QWidget *pTreeViewWidget = new QWidget;
+    QFileSystemModel *model = new QFileSystemModel;
+    model->setRootPath(QDir::currentPath());
+    QHBoxLayout *pTabLayout = new QHBoxLayout;
+    pTabLayout->setMargin(0);
+    pTabLayout->setMargin(0);
+    pTreeViewWidget->setLayout(pTabLayout);
+
+    QTreeView *tree = new QTreeView;
+    tree->setModel(model);
+    pTabLayout->addWidget(tree);
+
+    bottomLeftTabWidget->addTab(pTreeViewWidget, "&TreeView");
+    bottomLeftTabWidget->addTab(new QWidget(), "tab 2");
+    bottomLeftTabWidget->addTab(new QWidget(), "tab 3");
+    bottomLeftTabWidget->addTab(new QWidget(), "tab 4");
 }
 
 void WidgetGallery::createBottomRightGroupBox()
@@ -247,17 +309,24 @@ void WidgetGallery::createBottomRightGroupBox()
     lineEdit = new QLineEdit("s3cRe7");
     lineEdit->setEchoMode(QLineEdit::Password);
     lineEdit->setClearButtonEnabled(true);
+    lineEdit->setFrame(false);
 
     spinBox = new QSpinBox(bottomRightGroupBox);
     spinBox->setValue(50);
+    spinBox->setButtonSymbols(QAbstractSpinBox::PlusMinus);
+    spinBox->setPrefix(" Prefix ");
+    spinBox->setSuffix(" Suffix ");
+    spinBox->setAlignment(Qt::AlignCenter);
+    spinBox->setFrame(false);
 
     dateTimeEdit = new QDateTimeEdit(bottomRightGroupBox);
     dateTimeEdit->setDateTime(QDateTime::currentDateTime());
 
     comboBoxEdit = new QComboBox(bottomRightGroupBox);
-    comboBoxEdit->addItem(QIcon::fromTheme("state-ok"), "state-ok");
-    comboBoxEdit->addItem(QIcon::fromTheme("crosshairs"), "crosshairs");
-    comboBoxEdit->addItem(QIcon::fromTheme("audio-volume-low-symbolic"), "audio-volume-low-symbolic");
+    comboBoxEdit->addItem(QIcon::fromTheme("dde-file-manager"), "dde-file-manager");
+    comboBoxEdit->addItem(QIcon::fromTheme("dde-introduction"), "dde-introduction");
+    comboBoxEdit->addItem(QIcon::fromTheme("deepin-deb-installer"), "deepin-deb-installer");
+    comboBoxEdit->setEditable(true);
 
     slider = new QSlider(Qt::Horizontal, bottomRightGroupBox);
     slider->setRange(0, 100);
